package
Version:
v0.0.0-...-eb13a2d
Opens a new window with list of versions in this module.
Published: May 30, 2022
License: BSD-3-Clause
Opens a new window with license information.
Imports: 3
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Config struct {
Module string `yaml:"Module"`
Count uint32 `yaml:"Count"`
Input string `yaml:"Input"`
Threads uint16 `yaml:"Threads"`
Secret string `yaml:"Secret"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.